@@ -1,6 +1,6 @@
 /*
 
-  SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,9 +13,7 @@
 
 using namespace MailCommon;
 
-ExpireCollectionAttribute::ExpireCollectionAttribute()
-{
-}
+ExpireCollectionAttribute::ExpireCollectionAttribute() = default;
 
 QByteArray ExpireCollectionAttribute::type() const
 {
