@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef EXPIRECOLLECTIONATTRIBUTETEST_H
-#define EXPIRECOLLECTIONATTRIBUTETEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class ExpireCollectionAttributeTest : public QObject
     Q_OBJECT
 public:
     explicit ExpireCollectionAttributeTest(QObject *parent = nullptr);
-    ~ExpireCollectionAttributeTest();
+    ~ExpireCollectionAttributeTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldAssignValue_data();
@@ -26,4 +25,3 @@ private Q_SLOTS:
     void shouldHaveType();
 };
 
-#endif // EXPIRECOLLECTIONATTRIBUTETEST_H
