@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,7 +8,7 @@
 #include "folder/foldersettings.h"
 #include "kernel/mailkernel.h"
 #include "util/mailutil_p.h"
-#include <Akonadi/KMime/NewMailNotifierAttribute>
+#include <Akonadi/NewMailNotifierAttribute>
 #include <KIdentityManagement/IdentityCombo>
 #include <KLocalizedString>
 #include <QCheckBox>
@@ -66,9 +66,7 @@ CollectionGeneralWidget::CollectionGeneralWidget(QWidget *parent)
     topLayout->addRow(i18n("&Sender identity:"), mIdentityComboBox);
 }
 
-CollectionGeneralWidget::~CollectionGeneralWidget()
-{
-}
+CollectionGeneralWidget::~CollectionGeneralWidget() = default;
 
 void CollectionGeneralWidget::slotIdentityCheckboxChanged()
 {
@@ -97,6 +95,7 @@ void CollectionGeneralWidget::save(Akonadi::Collection &collection)
         mFolderCollection->setHideInSelectionDialog(mHideInSelectionDialogCheckBox->isChecked());
         mFolderCollection->writeConfig();
     }
+    mFolderCollection.reset();
 }
 
 void CollectionGeneralWidget::load(const Akonadi::Collection &col)
