@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERACTIONDELETETEST_H
-#define FILTERACTIONDELETETEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class FilterActionDeleteTest : public QObject
     Q_OBJECT
 public:
     explicit FilterActionDeleteTest(QObject *parent = nullptr);
-    ~FilterActionDeleteTest();
+    ~FilterActionDeleteTest() override;
 
 private Q_SLOTS:
     void shouldHaveDefaultValue();
@@ -24,4 +23,3 @@ private Q_SLOTS:
     void shouldDeleteItem();
 };
 
-#endif // FILTERACTIONDELETETEST_H
