@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef FILTERACTIONMISSINGIDENTITYDIALOGTEST_H
-#define FILTERACTIONMISSINGIDENTITYDIALOGTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,10 +13,9 @@ class FilterActionMissingIdentityDialogTest : public QObject
     Q_OBJECT
 public:
     explicit FilterActionMissingIdentityDialogTest(QObject *parent = nullptr);
-    ~FilterActionMissingIdentityDialogTest();
+    ~FilterActionMissingIdentityDialogTest() override;
 private Q_SLOTS:
     void initTestCase();
     void shouldHaveDefaultValue();
 };
 
-#endif // FILTERACTIONMISSINGIDENTITYDIALOGTEST_H
