@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERACTIONREPLYTOTEST_H
-#define FILTERACTIONREPLYTOTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class FilterActionReplyToTest : public QObject
     Q_OBJECT
 public:
     explicit FilterActionReplyToTest(QObject *parent = nullptr);
-    ~FilterActionReplyToTest();
+    ~FilterActionReplyToTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldBeEmpty();
@@ -24,4 +23,3 @@ private Q_SLOTS:
     void shouldNotCreateReplyToWhenAddressIsEmpty();
 };
 
-#endif // FILTERACTIONREPLYTOTEST_H
