@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERACTIONUNSETSTATUSTEST_H
-#define FILTERACTIONUNSETSTATUSTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,10 +13,9 @@ class FilterActionUnsetStatusTest : public QObject
     Q_OBJECT
 public:
     explicit FilterActionUnsetStatusTest(QObject *parent = nullptr);
-    ~FilterActionUnsetStatusTest();
+    ~FilterActionUnsetStatusTest() override;
 private Q_SLOTS:
     void shouldHaveSieveRequires();
     void shouldRequiresPart();
 };
 
-#endif // FILTERACTIONUNSETSTATUSTEST_H
