@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef INVALIDFILTERDIALOGTEST_H
-#define INVALIDFILTERDIALOGTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,9 +13,8 @@ class InvalidFilterDialogTest : public QObject
     Q_OBJECT
 public:
     explicit InvalidFilterDialogTest(QObject *parent = nullptr);
-    ~InvalidFilterDialogTest();
+    ~InvalidFilterDialogTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
 
-#endif // INVALIDFILTERDIALOGTEST_H
