@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -38,9 +38,7 @@ FilterImporterSylpheed::FilterImporterSylpheed(QFile *file)
     }
 }
 
-FilterImporterSylpheed::~FilterImporterSylpheed()
-{
-}
+FilterImporterSylpheed::~FilterImporterSylpheed() = default;
 
 QString FilterImporterSylpheed::defaultFiltersSettingsPath()
 {
