@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KMFILTERACCOUNTLIST_H
-#define KMFILTERACCOUNTLIST_H
+#pragma once
 
 #include <QTreeWidget>
 
@@ -25,8 +24,7 @@ public:
     void applyOnAccount(MailCommon::MailFilter *filter);
     void applyOnAccount(const QStringList &lst);
 
-    QStringList selectedAccount();
+    Q_REQUIRED_RESULT QStringList selectedAccount();
 };
 }
 
-#endif // KMFILTERACCOUNTLIST_H
