@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -13,9 +13,7 @@ MDNStateAttributeTest::MDNStateAttributeTest(QObject *parent)
 {
 }
 
-MDNStateAttributeTest::~MDNStateAttributeTest()
-{
-}
+MDNStateAttributeTest::~MDNStateAttributeTest() = default;
 
 void MDNStateAttributeTest::shouldHaveDefaultValue()
 {
