@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,39 +11,35 @@
 #include <KLineEdit>
 #include <KLocalizedString>
 
-#include <QStackedWidget>
-#include <QLabel>
 #include <QComboBox>
-
+#include <QLabel>
+#include <QStackedWidget>
+#include <KLazyLocalizedString>
 using namespace MailCommon;
 
 // also see SearchRule::matches() and SearchRule::Function
 // if you change the following strings!
 static const struct {
     SearchRule::Function id;
-    const char *displayName;
-} HeaderFunctions[] = {
-    { SearchRule::FuncContains, I18N_NOOP("contains")          },
-    { SearchRule::FuncContainsNot, I18N_NOOP("does not contain")   },
-    { SearchRule::FuncEquals, I18N_NOOP("equals")            },
-    { SearchRule::FuncNotEqual, I18N_NOOP("does not equal")     },
-    { SearchRule::FuncStartWith, I18N_NOOP("starts with")         },
-    { SearchRule::FuncNotStartWith, I18N_NOOP("does not start with")},
-    { SearchRule::FuncEndWith, I18N_NOOP("ends with")           },
-    { SearchRule::FuncNotEndWith, I18N_NOOP("does not end with")  },
+    const KLazyLocalizedString displayName;
+} HeaderFunctions[] = {{SearchRule::FuncContains, kli18n("contains")},
+                       {SearchRule::FuncContainsNot, kli18n("does not contain")},
+                       {SearchRule::FuncEquals, kli18n("equals")},
+                       {SearchRule::FuncNotEqual, kli18n("does not equal")},
+                       {SearchRule::FuncStartWith, kli18n("starts with")},
+                       {SearchRule::FuncNotStartWith, kli18n("does not start with")},
+                       {SearchRule::FuncEndWith, kli18n("ends with")},
+                       {SearchRule::FuncNotEndWith, kli18n("does not end with")},
 
-    { SearchRule::FuncRegExp, I18N_NOOP("matches regular expr.") },
-    { SearchRule::FuncNotRegExp, I18N_NOOP("does not match reg. expr.") },
-    { SearchRule::FuncIsInAddressbook, I18N_NOOP("is in address book") },
-    { SearchRule::FuncIsNotInAddressbook, I18N_NOOP("is not in address book") }
-};
-static const int HeadersFunctionCount
-    = sizeof(HeaderFunctions) / sizeof(*HeaderFunctions);
+                       {SearchRule::FuncRegExp, kli18n("matches regular expr.")},
+                       {SearchRule::FuncNotRegExp, kli18n("does not match reg. expr.")},
+                       {SearchRule::FuncIsInAddressbook, kli18n("is in address book")},
+                       {SearchRule::FuncIsNotInAddressbook, kli18n("is not in address book")}};
+static const int HeadersFunctionCount = sizeof(HeaderFunctions) / sizeof(*HeaderFunctions);
 
 //---------------------------------------------------------------------------
 
-QWidget *HeadersRuleWidgetHandler::createFunctionWidget(
-    int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const
+QWidget *HeadersRuleWidgetHandler::createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const
 {
     if (number != 0) {
         return nullptr;
@@ -53,14 +49,12 @@ QWidget *HeadersRuleWidgetHandler::createFunctionWidget(
     funcCombo->setMinimumWidth(50);
     funcCombo->setObjectName(QStringLiteral("headerRuleFuncCombo"));
     for (int i = 0; i < HeadersFunctionCount; ++i) {
-        if (!(isBalooSearch
-              && (HeaderFunctions[i].id == SearchRule::FuncIsInAddressbook || HeaderFunctions[i].id == SearchRule::FuncIsNotInAddressbook))) {
-            funcCombo->addItem(i18n(HeaderFunctions[i].displayName));
+        if (!(isBalooSearch && (HeaderFunctions[i].id == SearchRule::FuncIsInAddressbook || HeaderFunctions[i].id == SearchRule::FuncIsNotInAddressbook))) {
+            funcCombo->addItem(HeaderFunctions[i].displayName.toString());
         }
     }
     funcCombo->adjustSize();
-    QObject::connect(funcCombo, SIGNAL(activated(int)),
-                     receiver, SLOT(slotFunctionChanged()));
+    QObject::connect(funcCombo, SIGNAL(activated(int)), receiver, SLOT(slotFunctionChanged()));
     return funcCombo;
 }
 
@@ -69,20 +63,18 @@ QWidget *HeadersRuleWidgetHandler::createFunctionWidget(
 QWidget *HeadersRuleWidgetHandler::createValueWidget(int number, QStackedWidget *valueStack, const QObject *receiver) const
 {
     if (number == 0) {
-        auto *lineEdit = new KLineEdit(valueStack);
+        auto lineEdit = new KLineEdit(valueStack);
         lineEdit->setClearButtonEnabled(true);
         lineEdit->setTrapReturnKey(true);
         lineEdit->setObjectName(QStringLiteral("regExpLineEdit"));
-        QObject::connect(lineEdit, SIGNAL(textChanged(QString)),
-                         receiver, SLOT(slotValueChanged()));
-        QObject::connect(lineEdit, SIGNAL(returnPressed()),
-                         receiver, SLOT(slotReturnPressed()));
+        QObject::connect(lineEdit, SIGNAL(textChanged(QString)), receiver, SLOT(slotValueChanged()));
+        QObject::connect(lineEdit, SIGNAL(returnPressed()), receiver, SLOT(slotReturnPressed()));
         return lineEdit;
     }
 
     // blank QLabel to hide value widget for in-address-book rule
     if (number == 1) {
-        QLabel *label = new QLabel(valueStack);
+        auto label = new QLabel(valueStack);
         label->setObjectName(QStringLiteral("headerRuleValueHider"));
         label->setBuddy(valueStack);
         return label;
@@ -92,8 +84,7 @@ QWidget *HeadersRuleWidgetHandler::createValueWidget(int number, QStackedWidget
 
 //---------------------------------------------------------------------------
 
-SearchRule::Function HeadersRuleWidgetHandler::currentFunction(
-    const QStackedWidget *functionStack) const
+SearchRule::Function HeadersRuleWidgetHandler::currentFunction(const QStackedWidget *functionStack) const
 {
     const auto funcCombo = functionStack->findChild<QComboBox *>(QStringLiteral("headerRuleFuncCombo"));
 
@@ -117,7 +108,7 @@ SearchRule::Function HeadersRuleWidgetHandler::function(const QByteArray &field,
 //---------------------------------------------------------------------------
 QString HeadersRuleWidgetHandler::currentValue(const QStackedWidget *valueStack, SearchRule::Function func) const
 {
-    Q_UNUSED(func);
+    Q_UNUSED(func)
 
     const KLineEdit *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
 
@@ -126,7 +117,7 @@ QString HeadersRuleWidgetHandler::currentValue(const QStackedWidget *valueStack,
     }
 
     // or anything else, like addressbook
-    return QString();
+    return {};
 }
 
 //---------------------------------------------------------------------------
@@ -134,7 +125,7 @@ QString HeadersRuleWidgetHandler::currentValue(const QStackedWidget *valueStack,
 QString HeadersRuleWidgetHandler::value(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
     SearchRule::Function func = currentFunction(functionStack);
     if (func == SearchRule::FuncIsInAddressbook) {
@@ -151,7 +142,7 @@ QString HeadersRuleWidgetHandler::value(const QByteArray &field, const QStackedW
 QString HeadersRuleWidgetHandler::prettyValue(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     SearchRule::Function func = currentFunction(functionStack);
@@ -207,8 +198,7 @@ bool HeadersRuleWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWi
     }
 
     const SearchRule::Function func = rule->function();
-    if ((isBalooSearch
-         && (func == SearchRule::FuncIsInAddressbook || func == SearchRule::FuncIsNotInAddressbook))) {
+    if ((isBalooSearch && (func == SearchRule::FuncIsInAddressbook || func == SearchRule::FuncIsNotInAddressbook))) {
         reset(functionStack, valueStack);
         return false;
     }
@@ -233,13 +223,11 @@ bool HeadersRuleWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWi
         functionStack->setCurrentWidget(funcCombo);
     }
 
-    if (func == SearchRule::FuncIsInAddressbook
-        || func == SearchRule::FuncIsNotInAddressbook) {
+    if (func == SearchRule::FuncIsInAddressbook || func == SearchRule::FuncIsNotInAddressbook) {
         auto *w = valueStack->findChild<QWidget *>(QStringLiteral("headerRuleValueHider"));
         valueStack->setCurrentWidget(w);
     } else {
-        auto *lineEdit
-            = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
+        auto *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
 
         if (lineEdit) {
             lineEdit->blockSignals(true);
@@ -266,12 +254,10 @@ bool HeadersRuleWidgetHandler::update(const QByteArray &field, QStackedWidget *f
 
     // raise the correct value widget
     SearchRule::Function func = currentFunction(functionStack);
-    if (func == SearchRule::FuncIsInAddressbook
-        || func == SearchRule::FuncIsNotInAddressbook) {
+    if (func == SearchRule::FuncIsInAddressbook || func == SearchRule::FuncIsNotInAddressbook) {
         valueStack->setCurrentWidget(valueStack->findChild<QWidget *>(QStringLiteral("headerRuleValueHider")));
     } else {
-        auto *lineEdit
-            = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
+        auto *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
 
         if (lineEdit) {
             valueStack->setCurrentWidget(lineEdit);
