@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,45 +7,43 @@
 #include "messagerulewidgethandler.h"
 #include "search/searchpattern.h"
 
-#include <KLocalizedString>
 #include <KLineEdit>
-#include <QStackedWidget>
-#include <QLabel>
+#include <KLocalizedString>
 #include <QComboBox>
-
+#include <QLabel>
+#include <QStackedWidget>
+#include <KLazyLocalizedString>
 using namespace MailCommon;
 
 // also see SearchRule::matches() and SearchRule::Function
 // if you change the following strings!
 static const struct {
     SearchRule::Function id;
-    const char *displayName;
+    const KLazyLocalizedString displayName;
 } MessageFunctions[] = {
-    { SearchRule::FuncContains, I18N_NOOP("contains")          },
-    { SearchRule::FuncContainsNot, I18N_NOOP("does not contain")  },
-    { SearchRule::FuncRegExp, I18N_NOOP("matches regular expr.") },
-    { SearchRule::FuncNotRegExp, I18N_NOOP("does not match reg. expr.") },
-    { SearchRule::FuncHasAttachment, I18N_NOOP("has an attachment") },
-    { SearchRule::FuncHasNoAttachment, I18N_NOOP("has no attachment") },
+    {SearchRule::FuncContains, kli18n("contains")},
+    {SearchRule::FuncContainsNot, kli18n("does not contain")},
+    {SearchRule::FuncRegExp, kli18n("matches regular expr.")},
+    {SearchRule::FuncNotRegExp, kli18n("does not match reg. expr.")},
+    {SearchRule::FuncHasAttachment, kli18n("has an attachment")},
+    {SearchRule::FuncHasNoAttachment, kli18n("has no attachment")},
 };
-static const int MessageFunctionCount
-    = sizeof(MessageFunctions) / sizeof(*MessageFunctions);
+static const int MessageFunctionCount = sizeof(MessageFunctions) / sizeof(*MessageFunctions);
 
 //---------------------------------------------------------------------------
 
-QWidget *MessageRuleWidgetHandler::createFunctionWidget(
-    int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const
+QWidget *MessageRuleWidgetHandler::createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const
 {
     if (number != 0) {
         return nullptr;
     }
 
-    auto *funcCombo = new QComboBox(functionStack);
+    auto funcCombo = new QComboBox(functionStack);
     funcCombo->setMinimumWidth(50);
     funcCombo->setObjectName(QStringLiteral("messageRuleFuncCombo"));
     for (int i = 0; i < MessageFunctionCount; ++i) {
         if (!(isBalooSearch && (MessageFunctions[i].id == SearchRule::FuncHasAttachment || MessageFunctions[i].id == SearchRule::FuncHasNoAttachment))) {
-            funcCombo->addItem(i18n(MessageFunctions[i].displayName));
+            funcCombo->addItem(MessageFunctions[i].displayName.toString());
         }
     }
     funcCombo->adjustSize();
@@ -58,7 +56,7 @@ QWidget *MessageRuleWidgetHandler::createFunctionWidget(
 QWidget *MessageRuleWidgetHandler::createValueWidget(int number, QStackedWidget *valueStack, const QObject *receiver) const
 {
     if (number == 0) {
-        auto *lineEdit = new KLineEdit(valueStack);
+        auto lineEdit = new KLineEdit(valueStack);
         lineEdit->setClearButtonEnabled(true);
         lineEdit->setTrapReturnKey(true);
 
@@ -70,7 +68,7 @@ QWidget *MessageRuleWidgetHandler::createValueWidget(int number, QStackedWidget
 
     // blank QLabel to hide value widget for has-attachment rule
     if (number == 1) {
-        QLabel *label = new QLabel(valueStack);
+        auto label = new QLabel(valueStack);
         label->setObjectName(QStringLiteral("textRuleValueHider"));
         label->setBuddy(valueStack);
         return label;
@@ -81,8 +79,7 @@ QWidget *MessageRuleWidgetHandler::createValueWidget(int number, QStackedWidget
 
 //---------------------------------------------------------------------------
 
-SearchRule::Function MessageRuleWidgetHandler::currentFunction(
-    const QStackedWidget *functionStack) const
+SearchRule::Function MessageRuleWidgetHandler::currentFunction(const QStackedWidget *functionStack) const
 {
     const auto funcCombo = functionStack->findChild<QComboBox *>(QStringLiteral("messageRuleFuncCombo"));
 
@@ -114,7 +111,7 @@ QString MessageRuleWidgetHandler::currentValue(const QStackedWidget *valueStack,
         return lineEdit->text();
     }
 
-    return QString();
+    return {};
 }
 
 //---------------------------------------------------------------------------
@@ -122,7 +119,7 @@ QString MessageRuleWidgetHandler::currentValue(const QStackedWidget *valueStack,
 QString MessageRuleWidgetHandler::value(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     SearchRule::Function func = currentFunction(functionStack);
@@ -140,7 +137,7 @@ QString MessageRuleWidgetHandler::value(const QByteArray &field, const QStackedW
 QString MessageRuleWidgetHandler::prettyValue(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     SearchRule::Function func = currentFunction(functionStack);
@@ -222,8 +219,7 @@ bool MessageRuleWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWi
         functionStack->setCurrentWidget(funcCombo);
     }
 
-    if (func == SearchRule::FuncHasAttachment
-        || func == SearchRule::FuncHasNoAttachment) {
+    if (func == SearchRule::FuncHasAttachment || func == SearchRule::FuncHasNoAttachment) {
         auto *w = valueStack->findChild<QWidget *>(QStringLiteral("textRuleValueHider"));
         valueStack->setCurrentWidget(w);
     } else {
@@ -254,8 +250,7 @@ bool MessageRuleWidgetHandler::update(const QByteArray &field, QStackedWidget *f
 
     // raise the correct value widget
     SearchRule::Function func = currentFunction(functionStack);
-    if (func == SearchRule::FuncHasAttachment
-        || func == SearchRule::FuncHasNoAttachment) {
+    if (func == SearchRule::FuncHasAttachment || func == SearchRule::FuncHasNoAttachment) {
         auto *w = valueStack->findChild<QWidget *>(QStringLiteral("textRuleValueHider"));
         valueStack->setCurrentWidget(w);
     } else {
