@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,32 +7,28 @@
 #include "numericrulewidgethandler.h"
 #include "search/searchpattern.h"
 
-#include <KPluralHandlingSpinBox>
 #include <KLocalizedString>
+#include <KPluralHandlingSpinBox>
 
-#include <QStackedWidget>
 #include <QComboBox>
-
+#include <QStackedWidget>
+#include <KLazyLocalizedString>
 using namespace MailCommon;
 
 static const struct {
     SearchRule::Function id;
-    const char *displayName;
-} NumericFunctions[] = {
-    { SearchRule::FuncEquals, I18N_NOOP("is equal to")         },
-    { SearchRule::FuncNotEqual, I18N_NOOP("is not equal to")      },
-    { SearchRule::FuncIsGreater, I18N_NOOP("is greater than")     },
-    { SearchRule::FuncIsLessOrEqual, I18N_NOOP("is less than or equal to") },
-    { SearchRule::FuncIsLess, I18N_NOOP("is less than")        },
-    { SearchRule::FuncIsGreaterOrEqual, I18N_NOOP("is greater than or equal to") }
-};
-static const int NumericFunctionCount
-    = sizeof(NumericFunctions) / sizeof(*NumericFunctions);
+    const KLazyLocalizedString displayName;
+} NumericFunctions[] = {{SearchRule::FuncEquals, kli18n("is equal to")},
+                        {SearchRule::FuncNotEqual, kli18n("is not equal to")},
+                        {SearchRule::FuncIsGreater, kli18n("is greater than")},
+                        {SearchRule::FuncIsLessOrEqual, kli18n("is less than or equal to")},
+                        {SearchRule::FuncIsLess, kli18n("is less than")},
+                        {SearchRule::FuncIsGreaterOrEqual, kli18n("is greater than or equal to")}};
+static const int NumericFunctionCount = sizeof(NumericFunctions) / sizeof(*NumericFunctions);
 
 //---------------------------------------------------------------------------
 
-QWidget *NumericRuleWidgetHandler::createFunctionWidget(
-    int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
+QWidget *NumericRuleWidgetHandler::createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
 {
     if (number != 0) {
         return nullptr;
@@ -42,11 +38,10 @@ QWidget *NumericRuleWidgetHandler::createFunctionWidget(
     funcCombo->setMinimumWidth(50);
     funcCombo->setObjectName(QStringLiteral("numericRuleFuncCombo"));
     for (int i = 0; i < NumericFunctionCount; ++i) {
-        funcCombo->addItem(i18n(NumericFunctions[i].displayName));
+        funcCombo->addItem(NumericFunctions[i].displayName.toString());
     }
     funcCombo->adjustSize();
-    QObject::connect(funcCombo, SIGNAL(activated(int)),
-                     receiver, SLOT(slotFunctionChanged()));
+    QObject::connect(funcCombo, SIGNAL(activated(int)), receiver, SLOT(slotFunctionChanged()));
     return funcCombo;
 }
 
@@ -58,17 +53,15 @@ QWidget *NumericRuleWidgetHandler::createValueWidget(int number, QStackedWidget
         return nullptr;
     }
 
-    auto *numInput = new KPluralHandlingSpinBox(valueStack);
+    auto numInput = new KPluralHandlingSpinBox(valueStack);
     numInput->setObjectName(QStringLiteral("KPluralHandlingSpinBox"));
-    QObject::connect(numInput, SIGNAL(valueChanged(int)),
-                     receiver, SLOT(slotValueChanged()));
+    QObject::connect(numInput, SIGNAL(valueChanged(int)), receiver, SLOT(slotValueChanged()));
     return numInput;
 }
 
 //---------------------------------------------------------------------------
 
-SearchRule::Function NumericRuleWidgetHandler::currentFunction(
-    const QStackedWidget *functionStack) const
+SearchRule::Function NumericRuleWidgetHandler::currentFunction(const QStackedWidget *functionStack) const
 {
     const auto funcCombo = functionStack->findChild<QComboBox *>(QStringLiteral("numericRuleFuncCombo"));
 
@@ -100,7 +93,7 @@ QString NumericRuleWidgetHandler::currentValue(const QStackedWidget *valueStack)
         return QString::number(numInput->value());
     }
 
-    return QString();
+    return {};
 }
 
 //---------------------------------------------------------------------------
@@ -108,7 +101,7 @@ QString NumericRuleWidgetHandler::currentValue(const QStackedWidget *valueStack)
 QString NumericRuleWidgetHandler::value(const QByteArray &field, const QStackedWidget *, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     return currentValue(valueStack);
@@ -119,7 +112,7 @@ QString NumericRuleWidgetHandler::value(const QByteArray &field, const QStackedW
 QString NumericRuleWidgetHandler::prettyValue(const QByteArray &field, const QStackedWidget *, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     return currentValue(valueStack);
