@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,15 +13,15 @@
 #include <KLocalizedString>
 #include <QIcon>
 
-#include <Tag>
-#include <TagAttribute>
-#include <TagFetchJob>
-#include <TagFetchScope>
+#include <Akonadi/Tag>
+#include <Akonadi/TagAttribute>
+#include <Akonadi/TagFetchJob>
+#include <Akonadi/TagFetchScope>
 
 #include <QComboBox>
 #include <QLineEdit>
 #include <QStackedWidget>
-
+#include <KLazyLocalizedString>
 using namespace MailCommon;
 
 class FillTagComboJob : public KJob
@@ -89,13 +89,13 @@ void FillTagComboJob::onTagsFetched(KJob *job)
 
 static const struct {
     SearchRule::Function id;
-    const char *displayName;
-} TagFunctions[] = {{SearchRule::FuncContains, I18N_NOOP("contains")},
-                    {SearchRule::FuncContainsNot, I18N_NOOP("does not contain")},
-                    {SearchRule::FuncEquals, I18N_NOOP("equals")},
-                    {SearchRule::FuncNotEqual, I18N_NOOP("does not equal")},
-                    {SearchRule::FuncRegExp, I18N_NOOP("matches regular expr.")},
-                    {SearchRule::FuncNotRegExp, I18N_NOOP("does not match reg. expr.")}};
+    const KLazyLocalizedString displayName;
+} TagFunctions[] = {{SearchRule::FuncContains, kli18n("contains")},
+                    {SearchRule::FuncContainsNot, kli18n("does not contain")},
+                    {SearchRule::FuncEquals, kli18n("equals")},
+                    {SearchRule::FuncNotEqual, kli18n("does not equal")},
+                    {SearchRule::FuncRegExp, kli18n("matches regular expr.")},
+                    {SearchRule::FuncNotRegExp, kli18n("does not match reg. expr.")}};
 static const int TagFunctionCount = sizeof(TagFunctions) / sizeof(*TagFunctions);
 
 //---------------------------------------------------------------------------
@@ -112,10 +112,10 @@ QWidget *TagRuleWidgetHandler::createFunctionWidget(int number, QStackedWidget *
     for (int i = 0; i < TagFunctionCount; ++i) {
         if (isBalooSearch) {
             if (TagFunctions[i].id == SearchRule::FuncContains || TagFunctions[i].id == SearchRule::FuncContainsNot) {
-                funcCombo->addItem(i18n(TagFunctions[i].displayName));
+                funcCombo->addItem(TagFunctions[i].displayName.toString());
             }
         } else {
-            funcCombo->addItem(i18n(TagFunctions[i].displayName));
+            funcCombo->addItem(TagFunctions[i].displayName.toString());
         }
     }
     funcCombo->adjustSize();
@@ -176,7 +176,7 @@ SearchRule::Function TagRuleWidgetHandler::function(const QByteArray &field, con
 QString TagRuleWidgetHandler::value(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     SearchRule::Function func = function(field, functionStack);
@@ -187,7 +187,7 @@ QString TagRuleWidgetHandler::value(const QByteArray &field, const QStackedWidge
         if (lineEdit) {
             return lineEdit->text();
         } else {
-            return QString();
+            return {};
         }
     }
 
@@ -197,7 +197,7 @@ QString TagRuleWidgetHandler::value(const QByteArray &field, const QStackedWidge
     if (tagCombo) {
         return tagCombo->itemData(tagCombo->currentIndex()).toString();
     } else {
-        return QString();
+        return {};
     }
 }
 
