@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef SNIPPETSMANAGERTEST_H
-#define SNIPPETSMANAGERTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,9 +13,8 @@ class SnippetsManagerTest : public QObject
     Q_OBJECT
 public:
     explicit SnippetsManagerTest(QObject *parent = nullptr);
-    ~SnippetsManagerTest();
+    ~SnippetsManagerTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
 
-#endif // SNIPPETSMANAGERTEST_H
