@@ -1,38 +1,25 @@
 /*
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net,
-    Author: Tobias Koenig <tokoe@kdab.com>
-  Copyright (c) 2019-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Tobias Koenig <tokoe@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
+  SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_SNIPPETSMODEL_P_H
-#define MAILCOMMON_SNIPPETSMODEL_P_H
+#pragma once
 
+#include "mailcommon_export.h"
 #include <QAbstractItemModel>
 #include <QKeySequence>
-#include "mailcommon_export.h"
-namespace MailCommon {
+namespace MailCommon
+{
 class SnippetItem;
 /**
  * @brief The SnippetsInfo struct
  * @author Laurent Montel <montel@kde.org>
  */
-struct MAILCOMMON_EXPORT SnippetsInfo
-{
+struct MAILCOMMON_EXPORT SnippetsInfo {
     QString newName;
     QKeySequence keySequence;
     QString text;
@@ -54,15 +41,15 @@ class MAILCOMMON_EXPORT SnippetsModel : public QAbstractItemModel
 public:
     enum Role {
         IsGroupRole = Qt::UserRole + 1, ///< Returns whether the index represents a group
-        NameRole,                       ///< The name of a snippet or group
-        TextRole,                       ///< The text of a snippet
-        KeySequenceRole,                ///< The key sequence to activate a snippet
-        KeywordRole,                    ///< The keyword which will replace by snippet
-        SubjectRole,                    ///< The subject of a snippet
-        ToRole,                         ///< The To of a snippet
-        CcRole,                         ///< The Cc of a snippet
-        BccRole,                        ///< The Cc of a snippet
-        AttachmentRole,                 ///< The Attachment of a snippet
+        NameRole, ///< The name of a snippet or group
+        TextRole, ///< The text of a snippet
+        KeySequenceRole, ///< The key sequence to activate a snippet
+        KeywordRole, ///< The keyword which will replace by snippet
+        SubjectRole, ///< The subject of a snippet
+        ToRole, ///< The To of a snippet
+        CcRole, ///< The Cc of a snippet
+        BccRole, ///< The Cc of a snippet
+        AttachmentRole, ///< The Attachment of a snippet
     };
 
     static SnippetsModel *instance();
@@ -108,15 +95,31 @@ protected:
 Q_SIGNALS:
     void dndDone();
     void addNewDndSnippset(const QString &);
-    void updateActionCollection(const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment);
+    void updateActionCollection(const QString &oldName,
+                                const QString &newName,
+                                const QKeySequence &keySequence,
+                                const QString &text,
+                                const QString &subject,
+                                const QString &to,
+                                const QString &cc,
+                                const QString &bcc,
+                                const QString &attachment);
 
 private:
     QModelIndex createGroup(const QString &groupName);
-    void createSnippet(const QModelIndex &groupIndex, const QString &snippetName, const QString &snippetText, const QString &snippetKeySequence, const QString &snippetKeyword, const QString &snippetSubject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment);
+    void createSnippet(const QModelIndex &groupIndex,
+                       const QString &snippetName,
+                       const QString &snippetText,
+                       const QString &snippetKeySequence,
+                       const QString &snippetKeyword,
+                       const QString &snippetSubject,
+                       const QString &to,
+                       const QString &cc,
+                       const QString &bcc,
+                       const QString &attachment);
     SnippetItem *mRootItem = nullptr;
     QMap<QString, QString> mSavedVariables;
 };
 }
 Q_DECLARE_TYPEINFO(MailCommon::SnippetsInfo, Q_MOVABLE_TYPE);
 
-#endif
