@@ -30,18 +30,17 @@
 
 #include <MessageComposer/MessageHelper>
 
-#include <AgentManager>
-#include <Akonadi/KMime/MessageParts>
-#include <Akonadi/KMime/NewMailNotifierAttribute>
-#include <AkonadiCore/ServerManager>
-#include <EntityTreeModel>
-#include <ItemFetchJob>
-#include <ItemFetchScope>
-#include <entitymimetypefiltermodel.h>
+#include <Akonadi/AgentManager>
+#include <Akonadi/EntityMimeTypeFilterModel>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/MessageParts>
+#include <Akonadi/NewMailNotifierAttribute>
+#include <Akonadi/ServerManager>
 
 #include <KMime/KMimeMessage>
 
-#include <KColorScheme>
 #include <KIO/JobUiDelegate>
 #include <KJob>
 #include <collectionpage/attributes/expirecollectionattribute.h>
@@ -209,7 +208,7 @@ QString MailCommon::Util::convertFolderPathToCollectionStr(const QString &folder
 {
     Akonadi::Collection::Id newFolderId = MailCommon::Util::convertFolderPathToCollectionId(folder);
     if (newFolderId == -1) {
-        return QString();
+        return {};
     }
     return QString::number(newFolderId);
 }
